"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const apollo_link_1 = require("apollo-link");
const apollo_cache_inmemory_1 = require("apollo-cache-inmemory");
const apollo_cache_instorage_1 = require("apollo-cache-instorage");
const graphql_client_1 = require("vue-cli-plugin-apollo/graphql-client");
const pusher_js_1 = tslib_1.__importDefault(require("pusher-js"));
const CustomHeuristicFragmentMatcher_1 = tslib_1.__importDefault(require("./CustomHeuristicFragmentMatcher"));
const PusherLink_1 = tslib_1.__importDefault(require("./PusherLink"));
pusher_js_1.default.logToConsole = process.env.NODE_ENV !== 'production';
const AUTH_TOKEN = 'accessToken';
const httpEndpoint = process.env.VUE_APP_GRAPHQL_HTTP || 'http://127.0.0.1:3000/graphql';
const pusherLink = new PusherLink_1.default({
    pusher: new pusher_js_1.default(process.env.VUE_APP_PUSHER_KEY, {
        cluster: process.env.VUE_APP_PUSHER_CLUSTER,
        forceTLS: true,
        authEndpoint: `${process.env.VUE_APP_HTTP_ENDPOINT}/graphql/subscriptions/auth`,
        auth: {
            params: null,
            headers: {
                authorization: `Bearer ${localStorage.getItem(AUTH_TOKEN)}`,
            },
        },
    }),
});
const persistLink = new apollo_cache_instorage_1.PersistLink();
function shouldPersist(_, dataId, data) {
    console.log(_, dataId, data);
    return dataId === 'ROOT_QUERY' || (!data || !!data.__persist);
}
const cache = new apollo_cache_instorage_1.InStorageCache({
    dataIdFromObject: result => (result.__typename && result.uuid ? `${result.__typename}:${result.uuid}` : apollo_cache_inmemory_1.defaultDataIdFromObject(result)),
    fragmentMatcher: new CustomHeuristicFragmentMatcher_1.default(),
    storage: window.localStorage,
    prefix: 'vue-oop-apollo',
    shouldPersist,
});
const link = apollo_link_1.ApolloLink.from([
    persistLink,
    pusherLink,
]);
const { apolloClient, wsClient } = graphql_client_1.createApolloClient({
    httpEndpoint,
    tokenName: AUTH_TOKEN,
    link,
    connectToDevTools: process.env.NODE_ENV !== 'production',
    cache,
});
exports.apolloClient = apolloClient;
exports.wsClient = wsClient;
//# sourceMappingURL=apolloClient.js.map